@@ -17,7 +17,7 @@ def test_website_move():
                           location=current_room)
     game.pick_option(option_key, character)
     try:
-        text, options = game.get_room_info(character)
+        text, options = game.get_room_info(character, game.currency)
     except AVEGameOver:
         return {"room": "__GAMEOVER__"}
     except AVEWinner:
@@ -26,7 +26,7 @@ def test_website_move():
     for k, v in options.items():
         options_list.append((k, v))
     options_list = sorted(options_list, key=lambda x: x[0])
-    inventory_text = character.get_inventory(game.items)
+    inventory_text = character.get_inventory(game.items, game.currency)
 
     assert text == str(option_key) + " lead here"
     print(options_list)
